pub struct DependencyKind {
pub run_at_build: bool,
pub only_debug_builds: bool,
}Expand description
The kind of a dependency regarding when it is built or run
Fields
run_at_build: boolThe crate gets executed at some point at build time
only_debug_builds: boolThe crate is only ever built as a dev-dependency
Implementations
Sourceimpl DependencyKind
impl DependencyKind
Sourcepub const DEVELOPMENT: Self
pub const DEVELOPMENT: Self
A dependency that is not run at build and only included via dev-dependencies
Sourcepub const fn then(self, next: DependencyKind) -> Self
pub const fn then(self, next: DependencyKind) -> Self
Combine dependency kinds between a parent dependency and its edge to a child.
If either is a build dependency, this sets run_at_build, and if either is only included
in dev-dependencies, this sets only_debug_builds.
Sourcepub const fn merged_with(self, other: DependencyKind) -> Self
pub const fn merged_with(self, other: DependencyKind) -> Self
Combine dependency kinds for a crate version coming from different paths.
If either is a build dependency, this sets run_at_build, and only_debug_builds is only
set if both are only reachable via dev-dependencies.