pub type Included = BTreeMap<String, BTreeMap<Version, IncludedDependencyVersion>>;Expand description
The set of included packages, mapping from the crate name to a map from versions to the actual metadata
Aliased Type
pub struct Included { /* private fields */ }